This function generates a random sample from the multivariate normal distribution with mean mu and covariance matrix Sigma.
MASS_mvrnorm(n = 1, mu, Sigma, tol = 1e-06, empirical = FALSE, EISPACK = FALSE)A (n X p) matrix of random observations from the multivariate normal distribution. Updated: 26.10.2023.
Numeric integer. The number of observations to generate.
Numeric vector. The mean vector of the multivariate normal distribution.
Numeric matrix. The covariance matrix of the multivariate normal distribution.
Numeric. Tolerance for checking the positive definiteness of the covariance matrix.
Logical. Whether to return the empirical covariance matrix.
Logical. Whether to use the EISPACK routine instead of the LINPACK routine.