Learn R Programming

transforEmotion (version 0.1.5)

calculate_moving_average: Calculate the moving average for a time series

Description

This function calculates the moving average for a time series.

Usage

calculate_moving_average(data, window_size)

Value

Matrix or Data frame containing the moving average values.

Arguments

data

Matrix or Data frame. The time series data

window_size

Numeric integer. The size of the moving average window.