Large language models can be quite large and, when stored locally,
can take up a lot of space on your computer. The direct paths to where the
models are on your computer is not necessarily intuitive.
This function quickly identifies the models on your computer and
informs you which ones can be deleted from it to open up storage space