generate_q: Generate a matrix of Dynamic Error values for the DLO simulation
Description
This function generates a matrix of Dynamic Error values (q) for the DLO simulation.
Usage
generate_q(num_steps, sigma_q)
Value
A (num_steps X 3) matrix of Dynamic Error values for neutral, negative and positive emotion latent score.
Arguments
- num_steps
Numeric integer.
The number of time steps used in the simulation.
- sigma_q
Numeric.
Standard deviation of the Dynamic Error/